@@ -746,4 +746,153 @@ class PutLogResult(core.Gs2Result):
 
     def to_dict(self) -> Dict[str, Any]:
         return {
+        }
+
+
+class DescribeInsightsResult(core.Gs2Result):
+    items: List[Insight] = None
+    next_page_token: str = None
+
+    def with_items(self, items: List[Insight]) -> DescribeInsightsResult:
+        self.items = items
+        return self
+
+    def with_next_page_token(self, next_page_token: str) -> DescribeInsightsResult:
+        self.next_page_token = next_page_token
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[DescribeInsightsResult]:
+        if data is None:
+            return None
+        return DescribeInsightsResult()\
+            .with_items([
+                Insight.from_dict(data.get('items')[i])
+                for i in range(len(data.get('items')) if data.get('items') else 0)
+            ])\
+            .with_next_page_token(data.get('nextPageToken'))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "items": [
+                self.items[i].to_dict() if self.items[i] else None
+                for i in range(len(self.items) if self.items else 0)
+            ],
+            "nextPageToken": self.next_page_token,
+        }
+
+
+class CreateInsightResult(core.Gs2Result):
+    item: Insight = None
+
+    def with_item(self, item: Insight) -> CreateInsightResult:
+        self.item = item
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[CreateInsightResult]:
+        if data is None:
+            return None
+        return CreateInsightResult()\
+            .with_item(Insight.from_dict(data.get('item')))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "item": self.item.to_dict() if self.item else None,
+        }
+
+
+class GetInsightResult(core.Gs2Result):
+    item: Insight = None
+
+    def with_item(self, item: Insight) -> GetInsightResult:
+        self.item = item
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[GetInsightResult]:
+        if data is None:
+            return None
+        return GetInsightResult()\
+            .with_item(Insight.from_dict(data.get('item')))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "item": self.item.to_dict() if self.item else None,
+        }
+
+
+class DeleteInsightResult(core.Gs2Result):
+    item: Insight = None
+
+    def with_item(self, item: Insight) -> DeleteInsightResult:
+        self.item = item
+        return self
+
+    def get(self, key, default=None):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return default
+
+    def __getitem__(self, key):
+        items = self.to_dict()
+        if key in items.keys():
+            return items[key]
+        return None
+
+    @staticmethod
+    def from_dict(
+        data: Dict[str, Any],
+    ) -> Optional[DeleteInsightResult]:
+        if data is None:
+            return None
+        return DeleteInsightResult()\
+            .with_item(Insight.from_dict(data.get('item')))
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "item": self.item.to_dict() if self.item else None,
         }
\ No newline at end of file
