@@ -368,6 +368,7 @@ class QuestModel(core.Gs2Model):
     metadata: str = None
     contents: List[Contents] = None
     challenge_period_event_id: str = None
+    first_complete_acquire_actions: List[AcquireAction] = None
     consume_actions: List[ConsumeAction] = None
     failed_acquire_actions: List[AcquireAction] = None
     premise_quest_names: List[str] = None
@@ -392,6 +393,10 @@ class QuestModel(core.Gs2Model):
         self.challenge_period_event_id = challenge_period_event_id
         return self
 
+    def with_first_complete_acquire_actions(self, first_complete_acquire_actions: List[AcquireAction]) -> QuestModel:
+        self.first_complete_acquire_actions = first_complete_acquire_actions
+        return self
+
     def with_consume_actions(self, consume_actions: List[ConsumeAction]) -> QuestModel:
         self.consume_actions = consume_actions
         return self
@@ -498,6 +503,10 @@ class QuestModel(core.Gs2Model):
                 for i in range(len(data.get('contents')) if data.get('contents') else 0)
             ])\
             .with_challenge_period_event_id(data.get('challengePeriodEventId'))\
+            .with_first_complete_acquire_actions([
+                AcquireAction.from_dict(data.get('firstCompleteAcquireActions')[i])
+                for i in range(len(data.get('firstCompleteAcquireActions')) if data.get('firstCompleteAcquireActions') else 0)
+            ])\
             .with_consume_actions([
                 ConsumeAction.from_dict(data.get('consumeActions')[i])
                 for i in range(len(data.get('consumeActions')) if data.get('consumeActions') else 0)
@@ -521,6 +530,10 @@ class QuestModel(core.Gs2Model):
                 for i in range(len(self.contents) if self.contents else 0)
             ],
             "challengePeriodEventId": self.challenge_period_event_id,
+            "firstCompleteAcquireActions": [
+                self.first_complete_acquire_actions[i].to_dict() if self.first_complete_acquire_actions[i] else None
+                for i in range(len(self.first_complete_acquire_actions) if self.first_complete_acquire_actions else 0)
+            ],
             "consumeActions": [
                 self.consume_actions[i].to_dict() if self.consume_actions[i] else None
                 for i in range(len(self.consume_actions) if self.consume_actions else 0)
@@ -1153,6 +1166,7 @@ class QuestModelMaster(core.Gs2Model):
     metadata: str = None
     contents: List[Contents] = None
     challenge_period_event_id: str = None
+    first_complete_acquire_actions: List[AcquireAction] = None
     consume_actions: List[ConsumeAction] = None
     failed_acquire_actions: List[AcquireAction] = None
     premise_quest_names: List[str] = None
@@ -1187,6 +1201,10 @@ class QuestModelMaster(core.Gs2Model):
         self.challenge_period_event_id = challenge_period_event_id
         return self
 
+    def with_first_complete_acquire_actions(self, first_complete_acquire_actions: List[AcquireAction]) -> QuestModelMaster:
+        self.first_complete_acquire_actions = first_complete_acquire_actions
+        return self
+
     def with_consume_actions(self, consume_actions: List[ConsumeAction]) -> QuestModelMaster:
         self.consume_actions = consume_actions
         return self
@@ -1303,6 +1321,10 @@ class QuestModelMaster(core.Gs2Model):
                 for i in range(len(data.get('contents')) if data.get('contents') else 0)
             ])\
             .with_challenge_period_event_id(data.get('challengePeriodEventId'))\
+            .with_first_complete_acquire_actions([
+                AcquireAction.from_dict(data.get('firstCompleteAcquireActions')[i])
+                for i in range(len(data.get('firstCompleteAcquireActions')) if data.get('firstCompleteAcquireActions') else 0)
+            ])\
             .with_consume_actions([
                 ConsumeAction.from_dict(data.get('consumeActions')[i])
                 for i in range(len(data.get('consumeActions')) if data.get('consumeActions') else 0)
@@ -1330,6 +1352,10 @@ class QuestModelMaster(core.Gs2Model):
                 for i in range(len(self.contents) if self.contents else 0)
             ],
             "challengePeriodEventId": self.challenge_period_event_id,
+            "firstCompleteAcquireActions": [
+                self.first_complete_acquire_actions[i].to_dict() if self.first_complete_acquire_actions[i] else None
+                for i in range(len(self.first_complete_acquire_actions) if self.first_complete_acquire_actions else 0)
+            ],
             "consumeActions": [
                 self.consume_actions[i].to_dict() if self.consume_actions[i] else None
                 for i in range(len(self.consume_actions) if self.consume_actions else 0)
