@@ -683,6 +683,7 @@ class CreateQuestModelMasterRequest(core.Gs2Request):
     metadata: str = None
     contents: List[Contents] = None
     challenge_period_event_id: str = None
+    first_complete_acquire_actions: List[AcquireAction] = None
     consume_actions: List[ConsumeAction] = None
     failed_acquire_actions: List[AcquireAction] = None
     premise_quest_names: List[str] = None
@@ -715,6 +716,10 @@ class CreateQuestModelMasterRequest(core.Gs2Request):
         self.challenge_period_event_id = challenge_period_event_id
         return self
 
+    def with_first_complete_acquire_actions(self, first_complete_acquire_actions: List[AcquireAction]) -> CreateQuestModelMasterRequest:
+        self.first_complete_acquire_actions = first_complete_acquire_actions
+        return self
+
     def with_consume_actions(self, consume_actions: List[ConsumeAction]) -> CreateQuestModelMasterRequest:
         self.consume_actions = consume_actions
         return self
@@ -756,6 +761,10 @@ class CreateQuestModelMasterRequest(core.Gs2Request):
                 for i in range(len(data.get('contents')) if data.get('contents') else 0)
             ])\
             .with_challenge_period_event_id(data.get('challengePeriodEventId'))\
+            .with_first_complete_acquire_actions([
+                AcquireAction.from_dict(data.get('firstCompleteAcquireActions')[i])
+                for i in range(len(data.get('firstCompleteAcquireActions')) if data.get('firstCompleteAcquireActions') else 0)
+            ])\
             .with_consume_actions([
                 ConsumeAction.from_dict(data.get('consumeActions')[i])
                 for i in range(len(data.get('consumeActions')) if data.get('consumeActions') else 0)
@@ -781,6 +790,10 @@ class CreateQuestModelMasterRequest(core.Gs2Request):
                 for i in range(len(self.contents) if self.contents else 0)
             ],
             "challengePeriodEventId": self.challenge_period_event_id,
+            "firstCompleteAcquireActions": [
+                self.first_complete_acquire_actions[i].to_dict() if self.first_complete_acquire_actions[i] else None
+                for i in range(len(self.first_complete_acquire_actions) if self.first_complete_acquire_actions else 0)
+            ],
             "consumeActions": [
                 self.consume_actions[i].to_dict() if self.consume_actions[i] else None
                 for i in range(len(self.consume_actions) if self.consume_actions else 0)
@@ -856,6 +869,7 @@ class UpdateQuestModelMasterRequest(core.Gs2Request):
     metadata: str = None
     contents: List[Contents] = None
     challenge_period_event_id: str = None
+    first_complete_acquire_actions: List[AcquireAction] = None
     consume_actions: List[ConsumeAction] = None
     failed_acquire_actions: List[AcquireAction] = None
     premise_quest_names: List[str] = None
@@ -888,6 +902,10 @@ class UpdateQuestModelMasterRequest(core.Gs2Request):
         self.challenge_period_event_id = challenge_period_event_id
         return self
 
+    def with_first_complete_acquire_actions(self, first_complete_acquire_actions: List[AcquireAction]) -> UpdateQuestModelMasterRequest:
+        self.first_complete_acquire_actions = first_complete_acquire_actions
+        return self
+
     def with_consume_actions(self, consume_actions: List[ConsumeAction]) -> UpdateQuestModelMasterRequest:
         self.consume_actions = consume_actions
         return self
@@ -929,6 +947,10 @@ class UpdateQuestModelMasterRequest(core.Gs2Request):
                 for i in range(len(data.get('contents')) if data.get('contents') else 0)
             ])\
             .with_challenge_period_event_id(data.get('challengePeriodEventId'))\
+            .with_first_complete_acquire_actions([
+                AcquireAction.from_dict(data.get('firstCompleteAcquireActions')[i])
+                for i in range(len(data.get('firstCompleteAcquireActions')) if data.get('firstCompleteAcquireActions') else 0)
+            ])\
             .with_consume_actions([
                 ConsumeAction.from_dict(data.get('consumeActions')[i])
                 for i in range(len(data.get('consumeActions')) if data.get('consumeActions') else 0)
@@ -954,6 +976,10 @@ class UpdateQuestModelMasterRequest(core.Gs2Request):
                 for i in range(len(self.contents) if self.contents else 0)
             ],
             "challengePeriodEventId": self.challenge_period_event_id,
+            "firstCompleteAcquireActions": [
+                self.first_complete_acquire_actions[i].to_dict() if self.first_complete_acquire_actions[i] else None
+                for i in range(len(self.first_complete_acquire_actions) if self.first_complete_acquire_actions else 0)
+            ],
             "consumeActions": [
                 self.consume_actions[i].to_dict() if self.consume_actions[i] else None
                 for i in range(len(self.consume_actions) if self.consume_actions else 0)
